Crate kcr_ps_percona_com

Crate kcr_ps_percona_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the ps.percona.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

ps.percona.com/v1

  • PerconaServerMySQLBackup
  • PerconaServerMySQLRestore
  • PerconaServerMySQL

ps.percona.com/v1alpha1

  • PerconaServerMySQLBackup
  • PerconaServerMySQLRestore
  • PerconaServerMySQL

Modules

v1
v1alpha1