This crate contains kube-rs compatible bindings for Kubernetes custom resources for the ps.percona.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
ps.percona.com/v1
PerconaServerMySQLBackupPerconaServerMySQLRestorePerconaServerMySQL
ps.percona.com/v1alpha1
PerconaServerMySQLBackupPerconaServerMySQLRestorePerconaServerMySQL